about summary refs log tree commit diff
path: root/iconv/loop.c
diff options
context:
space:
mode:
Diffstat (limited to 'iconv/loop.c')
-rw-r--r--iconv/loop.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/iconv/loop.c b/iconv/loop.c
index b8e798682e..9d168d84e9 100644
--- a/iconv/loop.c
+++ b/iconv/loop.c
@@ -190,9 +190,9 @@
 	if (result != __GCONV_ILLEGAL_INPUT)				      \
 	  break;							      \
       }									      \
     /* If any of them recognized the input stop.  */			      \
     if (result != __GCONV_ILLEGAL_INPUT)				      \
-      break;								      \
+      continue;								      \
 									      \
     /* Next see whether we have to ignore the error.  If not, stop.  */	      \
     if (! ignore_errors_p ())						      \
@@ -190,9 +190,9 @@
 	  break;							      \
       }									      \
-    /* If any of them recognized the input stop.  */			      \
+    /* If any of them recognized the input continue with the loop.  */	      \
     if (result != __GCONV_ILLEGAL_INPUT)				      \